@@ -832,7 +832,8 @@ gst_vaapi_display_destroy (GstVaapiDisplay * display)
   }
 
   if (priv->display) {
-    vaTerminate (priv->display);
+    if (!priv->parent)
+      vaTerminate (priv->display);
     priv->display = NULL;
   }
 
@@ -847,6 +848,8 @@ gst_vaapi_display_destroy (GstVaapiDisplay * display)
 
   g_free (priv->vendor_string);
   priv->vendor_string = NULL;
+
+  gst_vaapi_display_replace_internal (&priv->parent, NULL);
 }
 
 static gboolean
@@ -893,8 +896,10 @@ gst_vaapi_display_create_unlocked (GstVaapiDisplay * display,
   if (!priv->display)
     return FALSE;
 
-  if (!vaapi_initialize (priv->display))
-    return FALSE;
+  if (!priv->parent) {
+    if (!vaapi_initialize (priv->display))
+      return FALSE;
+  }
 
   GST_INFO_OBJECT (display, "new display addr=%p", display);
   g_free (priv->display_name);
@@ -914,6 +919,8 @@ gst_vaapi_display_lock_default (GstVaapiDisplay * display)
 {
   GstVaapiDisplayPrivate *priv = GST_VAAPI_DISPLAY_GET_PRIVATE (display);
 
+  if (priv->parent)
+    priv = GST_VAAPI_DISPLAY_GET_PRIVATE (priv->parent);
   g_rec_mutex_lock (&priv->mutex);
 }
 
@@ -922,6 +929,8 @@ gst_vaapi_display_unlock_default (GstVaapiDisplay * display)
 {
   GstVaapiDisplayPrivate *priv = GST_VAAPI_DISPLAY_GET_PRIVATE (display);
 
+  if (priv->parent)
+    priv = GST_VAAPI_DISPLAY_GET_PRIVATE (priv->parent);
   g_rec_mutex_unlock (&priv->mutex);
 }
 
